@@ -48,8 +48,12 @@ catalog = function(folder, ...)
   if (!dir.exists(folder))
     lidRError("CTG2")
 
+  verbose("Looking for las or laz files...")
+
   files <- list.files(folder, full.names = T, pattern = "(?i)\\.la(s|z)$", ...)
 
+  verbose("Reading files...")
+
   headers <- lapply(files, function(x)
   {
     header = rlas::readlasheader(x)
@@ -64,4 +68,4 @@ catalog = function(folder, ...)
   class(headers) = append("Catalog", class(headers))
 
   return(headers)
-}
\ No newline at end of file
+}
